@@ -59,6 +59,7 @@ class PerturbFlow(nn.Module):
                  input_size: int,
                  codebook_size: int = 200,
                  cell_factor_size: int = 0,
+                 cell_factor_effect_discrete: bool = False,
                  supervised_mode: bool = False,
                  z_dim: int = 10,
                  z_dist: Literal['normal','studentt','laplacian','cauchy','gumbel'] = 'gumbel',
@@ -74,7 +75,6 @@ class PerturbFlow(nn.Module):
                  use_cuda: bool = True,
                  seed: int = 42,
                  zero_bias: bool|list = True,
-                 enumrate: bool = False,
                  dtype = torch.float32, # type: ignore
                  ):
         super().__init__()
@@ -103,7 +103,7 @@ class PerturbFlow(nn.Module):
         else:
             self.use_bias = [not zero_bias] * self.cell_factor_size
         #self.use_bias = not zero_bias
-        self.enumrate = enumrate
+        self.enumrate = cell_factor_effect_discrete
         
         self.codebook_weights = None
 
@@ -432,8 +432,6 @@ class PerturbFlow(nn.Module):
 
             if self.cell_factor_size>0:
                 if self.enumrate:
-                    idx = torch.argmax(ns, dim=1)
-                    zn_loc = acs_loc[idx]
                     zus = self._total_effects(zn_loc, us)
                 else:
                     zus = self._total_effects(zns, us)
@@ -639,8 +637,6 @@ class PerturbFlow(nn.Module):
                 #    else:
                 #        zus = zus + self.cell_factor_effect[i]([zns,us[:,i].reshape(-1,1)])
                 if self.enumrate:
-                    idx = torch.argmax(ns, dim=1)
-                    zn_loc = acs_loc[idx]
                     zus = self._total_effects(zn_loc, us)
                 else:
                     zus = self._total_effects(zns, us)
