@@ -369,12 +369,13 @@ class SURE(nn.Module):
 
             zs = zns
             concentrate = self.decoder_concentrate(zs)
-            if self.loss_func == 'bernoulli':
+            if self.loss_func in ['bernoulli']:
                 log_theta = concentrate
             else:
                 rate = concentrate.exp()
-                if self.loss_func != 'poisson':
-                    theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                if self.loss_func == 'poisson':
+                    rate = theta * torch.sum(xs, dim=1, keepdim=True)
 
             if self.loss_func == 'negbinomial':
                 if self.use_zeroinflate:
@@ -451,12 +452,13 @@ class SURE(nn.Module):
                 zs = zns
 
             concentrate = self.decoder_concentrate(zs)
-            if self.loss_func == 'bernoulli':
+            if self.loss_func in ['bernoulli']:
                 log_theta = concentrate
             else:
                 rate = concentrate.exp()
-                if self.loss_func != 'poisson':
-                    theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                if self.loss_func == 'poisson':
+                    rate = theta * torch.sum(xs, dim=1, keepdim=True)
 
             if self.loss_func == 'negbinomial':
                 if self.use_zeroinflate:
@@ -545,12 +547,13 @@ class SURE(nn.Module):
             zs = zns
 
             concentrate = self.decoder_concentrate(zs)
-            if self.loss_func == 'bernoulli':
+            if self.loss_func in ['bernoulli']:
                 log_theta = concentrate
             else:
                 rate = concentrate.exp()
-                if self.loss_func != 'poisson':
-                    theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                if self.loss_func == 'poisson':
+                    rate = theta * torch.sum(xs, dim=1, keepdim=True)
 
             if self.loss_func == 'negbinomial':
                 if self.use_zeroinflate:
@@ -641,13 +644,14 @@ class SURE(nn.Module):
                 zs = zns
 
             concentrate = self.decoder_concentrate(zs)
-            if self.loss_func == 'bernoulli':
+            if self.loss_func in ['bernoulli']:
                 log_theta = concentrate
             else:
                 rate = concentrate.exp()
-                if self.loss_func != 'poisson':
-                    theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
-
+                theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+                if self.loss_func == 'poisson':
+                    rate = theta * torch.sum(xs, dim=1, keepdim=True)
+                    
             if self.loss_func == 'negbinomial':
                 if self.use_zeroinflate:
                     pyro.sample('x', dist.ZeroInflatedDistribution(dist.NegativeBinomial(total_count=total_count, probs=theta),gate_logits=gate_logits).to_event(1), obs=xs)
